@@ -376,9 +376,9 @@ class TokenList(Token):
         """Inserts *token* before *where*."""
         self.tokens.insert(self.token_index(where), token)
 
-    def insert_after(self, where, token):
+    def insert_after(self, where, token, skip_ws=True):
         """Inserts *token* after *where*."""
-        next_token = self.token_next(where)
+        next_token = self.token_next(where, skip_ws=skip_ws)
         if next_token is None:
             self.tokens.append(token)
         else:
